@@ -2,6 +2,7 @@ from typing import List, Dict
 
 from moviebotapi import Session
 from moviebotapi.core import utils
+from moviebotapi.core.basemodel import BaseModel
 from moviebotapi.core.models import MediaType
 from moviebotapi.core.utils import json_object
 
@@ -69,6 +70,18 @@ class MediaItem:
         utils.copy_value(data, self)
 
 
+class MediaFolder(BaseModel):
+    """媒体服务器配置的影音库文件夹"""
+    id: str
+    name: str
+    path: str
+    sub_folders: list
+
+
+ListMediaItem = List[MediaItem]
+ListMediaFolder = List[MediaFolder]
+
+
 class MediaServerApi:
     def __init__(self, session: Session):
         self._session: Session = session
